@@ -170,6 +170,16 @@ class Kitchen(arcade.Window):
         if name not in self.rubbish_textures:
             self.rubbish_textures.insert(0, TEXTUREPATH + name)
 
+    def add_my_misc(self, pic, x=0, y=0, scale=1, center=True):
+        m = arcade.Sprite(pic, scale)
+        if center:
+            m.center_x = self.width / 2 + x
+            m.center_y = self.height / 2 + y
+        else:
+            m.center_x = x
+            m.center_y = y
+        self.miscs.append(m)
+
     def add_my_rub(self, pic):
         self.rubbish_textures.insert(0, pic)
 
